@@ -42,7 +42,7 @@ namespace BOOM{
   {
    public:
     OrdinalCutpointBetaLogLikelihood(const OrdinalCutpointModel *m_);
-    double operator()(const Vec & beta)const;
+    double operator()(const Vector & beta)const override;
    private:
     const OrdinalCutpointModel *m_;
   };
@@ -52,7 +52,7 @@ namespace BOOM{
   {
    public:
     OrdinalCutpointDeltaLogLikelihood(const OrdinalCutpointModel *m_);
-    double operator()(const Vec & delta)const;
+    double operator()(const Vector & delta)const override;
    private:
     const OrdinalCutpointModel *m_;
   };
@@ -66,34 +66,34 @@ namespace BOOM{
   {
 
   public:
-    OrdinalCutpointModel(const Vec &beta, const Vec & delta);
-    OrdinalCutpointModel(const Vec &beta,
+    OrdinalCutpointModel(const Vector &beta, const Vector & delta);
+    OrdinalCutpointModel(const Vector &beta,
                          const Selector &Inc,
-                         const Vec & delta);
+                         const Vector & delta);
     OrdinalCutpointModel(const Selector &Inc, uint Maxscore);
-    OrdinalCutpointModel(const Mat &X, const Vec &y);
+    OrdinalCutpointModel(const Matrix &X, const Vector &y);
     OrdinalCutpointModel(const OrdinalCutpointModel &rhs);
 
-    virtual OrdinalCutpointModel *clone()const=0;
+    OrdinalCutpointModel *clone()const override =0;
 
     // link_inv(eta) = probability
     // link(prob) = eta
     virtual double link_inv(double)const=0;  // logit or probit
     virtual double dlink_inv(double)const=0; // derivative of link_inv
 
-    virtual GlmCoefs & coef();
-    virtual const GlmCoefs & coef()const;
-    virtual Ptr<GlmCoefs> coef_prm();
-    virtual const Ptr<GlmCoefs> coef_prm()const;
+    GlmCoefs & coef() override;
+    const GlmCoefs & coef()const override;
+    Ptr<GlmCoefs> coef_prm() override;
+    const Ptr<GlmCoefs> coef_prm()const override;
 
     Ptr<VectorParams> Delta_prm();
     const Ptr<VectorParams> Delta_prm()const;
 
     // inherits [Bb]eta()/set_[Bb]eta() from GlmModel
     double delta(uint)const; // delta[0] = - infinity, delta[1] = 0
-    const Vec & delta()const;
-    void set_delta(const Vec &d);
-    bool check_delta(const Vec & Delta)const;  // if Delta satisfies constraint
+    const Vector & delta()const;
+    void set_delta(const Vector &d);
+    bool check_delta(const Vector & Delta)const;  // if Delta satisfies constraint
 
     // Args:
     //   beta_delta: A vector with leading elements corresponding to
@@ -105,21 +105,21 @@ namespace BOOM{
     //   h: Hessian matrix (unused if nd < 2).  Dimension must match
     //     beta_delta.
     //   nd:  The number of derivatives desired.
-    virtual double Loglike(const Vector &beta_delta,
-                           Vector &g, Matrix &h, uint nd)const;
-    double log_likelihood(const Vec & beta, const Vec & delta)const;
+    double Loglike(const Vector &beta_delta,
+                           Vector &g, Matrix &h, uint nd)const override;
+    double log_likelihood(const Vector & beta, const Vector & delta)const;
     OrdinalCutpointBetaLogLikelihood beta_log_likelihood()const;
     OrdinalCutpointDeltaLogLikelihood delta_log_likelihood()const;
 
-    void initialize_params();
-    void initialize_params(const Vec &counts);
+    void initialize_params() override;
+    void initialize_params(const Vector &counts);
 
-    Vec CDF(const Vec &x)const; // Pr(Y<y)
+    Vector CDF(const Vector &x)const; // Pr(Y<y)
 
     virtual double pdf(dPtr, bool)const;
     double pdf(Ptr<OrdinalRegressionData>, bool)const;
-    double pdf(const OrdinalData &y, const Vec &x, bool logscale)const;
-    double pdf(uint y, const Vec &x, bool logscale)const;
+    double pdf(const OrdinalData &y, const Vector &x, bool logscale)const;
+    double pdf(uint y, const Vector &x, bool logscale)const;
 
     uint maxscore()const; // maximum possible score allowed
 
@@ -127,8 +127,8 @@ namespace BOOM{
 
   private:
     // interface is complicated
-    double bd_loglike(Vec & gbeta, Vec &gdelta, Mat & Hbeta, Mat &Hdelta,
-		      Mat & Hbd, uint nd, bool b_derivs, bool d_derivs) const;
+    double bd_loglike(Vector & gbeta, Vector &gdelta, Matrix & Hbeta, Matrix &Hdelta,
+                      Matrix & Hbd, uint nd, bool b_derivs, bool d_derivs) const;
     Ptr<CatKey> simulation_key_;
     virtual double simulate_latent_variable()const=0;  // from the link distribution
   };
