@@ -65,27 +65,38 @@ namespace BOOM{
     void observe_time_dimension(int max_time) override;
 
     void observe_state(const ConstVectorView then,
-                               const ConstVectorView now,
-                               int time_now) override;
-    uint state_dimension()const override{return 2;}
+                       const ConstVectorView now,
+                       int time_now) override;
+    uint state_dimension() const override{return 2;}
+    uint state_error_dimension() const override {return state_dimension();}
+
+    // This implementation throws, because this model cannot be part
+    // of an EM algorithm.
+    void update_complete_data_sufficient_statistics(
+        int t,
+        const ConstVectorView &state_error_mean,
+        const ConstSubMatrix &state_error_variance) override;
 
     // The state error simulation is conditional on the value of the
     // latent variance weights.  It needs to be that way so that
     // latent data imputation can work properly.
-    void simulate_state_error(VectorView eta, int t)const override;
-    void simulate_marginal_state_error(VectorView eta, int t)const;
-    void simulate_conditional_state_error(VectorView eta, int t)const;
+    void simulate_state_error(VectorView eta, int t) const override;
+    void simulate_marginal_state_error(VectorView eta, int t) const;
+    void simulate_conditional_state_error(VectorView eta, int t) const;
 
-    Ptr<SparseMatrixBlock> state_transition_matrix(int t)const override;
-    Ptr<SparseMatrixBlock> state_variance_matrix(int t)const override;
-    Ptr<SparseMatrixBlock> conditional_state_variance_matrix(int t)const;
-    Ptr<SparseMatrixBlock> marginal_state_variance_matrix(int t)const;
+    Ptr<SparseMatrixBlock> state_transition_matrix(int t) const override;
+    Ptr<SparseMatrixBlock> state_variance_matrix(int t) const override;
+    Ptr<SparseMatrixBlock> conditional_state_variance_matrix(int t) const;
+    Ptr<SparseMatrixBlock> marginal_state_variance_matrix(int t) const;
 
-    SparseVector observation_matrix(int t)const override;
+    Ptr<SparseMatrixBlock> state_error_expander(int t) const override;
+    Ptr<SparseMatrixBlock> state_error_variance(int t) const override;
 
-    Vector initial_state_mean()const override;
+    SparseVector observation_matrix(int t) const override;
+
+    Vector initial_state_mean() const override;
     void set_initial_state_mean(const Vector &v);
-    SpdMatrix initial_state_variance()const override;
+    SpdMatrix initial_state_variance() const override;
     void set_initial_state_variance(const SpdMatrix &V);
 
     // With "marginal" behavior set the model acts like a T
@@ -99,17 +110,17 @@ namespace BOOM{
     Ptr<UnivParams> NuLevel_prm();
     Ptr<UnivParams> SigsqSlope_prm();
     Ptr<UnivParams> NuSlope_prm();
-    const Ptr<UnivParams> SigsqLevel_prm()const;
-    const Ptr<UnivParams> NuLevel_prm()const;
-    const Ptr<UnivParams> SigsqSlope_prm()const;
-    const Ptr<UnivParams> NuSlope_prm()const;
+    const Ptr<UnivParams> SigsqLevel_prm() const;
+    const Ptr<UnivParams> NuLevel_prm() const;
+    const Ptr<UnivParams> SigsqSlope_prm() const;
+    const Ptr<UnivParams> NuSlope_prm() const;
 
-    double sigma_level()const;
-    double sigsq_level()const;
-    double nu_level()const;
-    double sigma_slope()const;
-    double sigsq_slope()const;
-    double nu_slope()const;
+    double sigma_level() const;
+    double sigsq_level() const;
+    double nu_level() const;
+    double sigma_slope() const;
+    double sigsq_slope() const;
+    double nu_slope() const;
 
     void set_sigma_level(double sigma);
     void set_sigsq_level(double sigsq);
@@ -119,22 +130,24 @@ namespace BOOM{
     void set_nu_slope(double nu);
 
     void clear_data() override;
-    const WeightedGaussianSuf & sigma_level_complete_data_suf()const;
-    const WeightedGaussianSuf & sigma_slope_complete_data_suf()const;
-    const GammaSuf & nu_level_complete_data_suf()const;
-    const GammaSuf & nu_slope_complete_data_suf()const;
+    const WeightedGaussianSuf & sigma_level_complete_data_suf() const;
+    const WeightedGaussianSuf & sigma_slope_complete_data_suf() const;
+    const GammaSuf & nu_level_complete_data_suf() const;
+    const GammaSuf & nu_slope_complete_data_suf() const;
 
     // Posterior draws for the weights in the normal mixture
     // representation of the T distribution.  For Gaussian models the
     // weights will be around 1.  A large outlier has a small weight.
-    const Vector & latent_level_weights()const;
-    const Vector & latent_slope_weights()const;
+    const Vector & latent_level_weights() const;
+    const Vector & latent_slope_weights() const;
+
    private:
-    void check_dim(const ConstVectorView &)const;
+    void check_dim(const ConstVectorView &) const;
 
     SparseVector observation_matrix_;
     Ptr<LocalLinearTrendMatrix> state_transition_matrix_;
     Ptr<DiagonalMatrixBlock> state_variance_matrix_;
+    Ptr<IdentityMatrix> state_error_expander_;
 
     Vector initial_state_mean_;
     SpdMatrix initial_state_variance_;
@@ -151,6 +164,5 @@ namespace BOOM{
     StateModel::Behavior behavior_;
   };
 
-
-}
+}  // namespace BOOM
 #endif // BOOM_LOCAL_LINEAR_TREND_STATE_MODEL_HPP_
