@@ -22,6 +22,8 @@
 #include <Models/Policies/PriorPolicy.hpp>
 #include <Models/SpdParams.hpp>
 
+#include <LinAlg/CorrelationMatrix.hpp>
+
 namespace BOOM{
 
   class UniformCorrelationModel
@@ -37,10 +39,10 @@ namespace BOOM{
 
     void initialize_params();
     double pdf(Ptr<Data>, bool logscale)const;
-    double logp(const Corr &)const override;
+    double logp(const CorrelationMatrix &)const override;
 
     uint dim()const;
-    Corr sim()const;
+    CorrelationMatrix sim()const;
   private:
     uint dim_;
   };
