@@ -20,12 +20,11 @@
 #include <cpputil/report_error.hpp>
 #include <cpputil/math_utils.hpp>
 #include <Bmath/Bmath.hpp>
+#include <distributions.hpp>
 #include <stats/moments.hpp>
 
 namespace BOOM {
   using Rmath::lgammafn;
-  using Rmath::trigamma;
-  using Rmath::digamma;
 
   BinomialData::BinomialData(int64_t n, int64_t y)
       : trials_(n), successes_(y)
@@ -240,6 +239,11 @@ namespace BOOM {
     return ans;
   }
 
+  int64_t BetaBinomialModel::sim(int64_t n)const{
+    double rate = rbeta(a(), b());
+    return rbinom(n, rate);
+  }
+
   // Set a/(a+b) and a+b using a very rough method of moments
   // estimator.  The estimator can fail if either the sample mean or
   // the sample variance is zero, in which case this function will
