@@ -18,7 +18,7 @@
 
 #include <Models/Glm/WeightedRegressionModel.hpp>
 #include <distributions.hpp>
-#include <LinAlg/Types.hpp>
+
 #include <cmath>
 #include <cpputil/math_utils.hpp>
 #include <Models/PosteriorSamplers/PosteriorSampler.hpp>
@@ -149,6 +149,15 @@ namespace BOOM{
     for (uint i=0; i < dp->size(); ++i) update((*dp)[i]);
   }
 
+  //------------------------------------------------------------
+  void WRS::set_xtwx(const SpdMatrix &xtwx) {
+    xtwx_ = xtwx;
+  }
+
+  void WRS::set_xtwy(const Vector &xtwy) {
+    xtwy_ = xtwy;
+  }
+
   //------------------------------------------------------------
 
   void WRS::add_data(const Vector &x, double y, double w) {
