@@ -26,7 +26,7 @@ namespace BOOM{
 
   typedef StateSpaceModel SSM;
 
-  void SSM::setup(){
+  void SSM::setup() {
     observe(observation_model_->Sigsq_prm());
     observation_model_->only_keep_sufstats();
     ParamPolicy::add_model(observation_model_);
@@ -39,12 +39,13 @@ namespace BOOM{
   }
 
   SSM::StateSpaceModel(const Vector &y, const std::vector<bool> &y_is_observed)
-      : observation_model_(new ZeroMeanGaussianModel(sqrt(var(y, y_is_observed))/10))
+      : observation_model_(new ZeroMeanGaussianModel(
+            sqrt(var(y, y_is_observed))/10))
   {
     setup();
-    for(int i = 0; i < y.size(); ++i){
+    for(int i = 0; i < y.size(); ++i) {
       NEW(DoubleData, dp)(y[i]);
-      if(!y_is_observed.empty() && !y_is_observed[i]){
+      if(!y_is_observed.empty() && !y_is_observed[i]) {
         dp->set_missing_status(Data::completely_missing);
       }
       add_data(dp);
@@ -61,26 +62,29 @@ namespace BOOM{
     setup();
   }
 
-  SSM * SSM::clone()const{return new SSM(*this);}
+  SSM* SSM::clone() const {return new SSM(*this);}
 
-  int SSM::time_dimension()const{return dat().size();}
+  int SSM::time_dimension() const {return dat().size();}
 
-  double SSM::observation_variance(int)const{
+  double SSM::observation_variance(int) const {
     return observation_model_->sigsq();}
 
-  double SSM::adjusted_observation(int t)const{
+  double SSM::adjusted_observation(int t) const {
     return dat()[t]->value(); }
 
-  bool SSM::is_missing_observation(int t)const{
+  bool SSM::is_missing_observation(int t) const {
     return dat()[t]->missing() != Data::observed;
   }
 
-  ZeroMeanGaussianModel* SSM::observation_model(){
-    return observation_model_.get();}
-  const ZeroMeanGaussianModel* SSM::observation_model()const{
-    return observation_model_.get();}
+  ZeroMeanGaussianModel* SSM::observation_model() {
+    return observation_model_.get();
+  }
 
-  void SSM::observe_data_given_state(int t){
+  const ZeroMeanGaussianModel* SSM::observation_model() const {
+    return observation_model_.get();
+  }
+
+  void SSM::observe_data_given_state(int t) {
     // Assuming ignorable missing data.
     if(!is_missing_observation(t)) {
       double mu = observation_matrix(t).dot(state(t));
@@ -91,61 +95,65 @@ namespace BOOM{
 
   // TODO(stevescott): should observation_matrix and
   // observation_variance be called with t + t0 + 1?
-  Matrix SSM::forecast(int n){
+  Matrix SSM::forecast(int n) {
     // TODO(stevescott): This method only works with truly Gaussian
     // state models.  We should put in a check to make sure that none
     // of the state models are T, normal mixture, etc.
     ScalarKalmanStorage ks(filter());
     Matrix ans(n, 2);
     int t0 = time_dimension();
-    for(int t = 0; t < n; ++t){
-      ans(t,0) = observation_matrix(t+t0).dot(ks.a);
-      sparse_scalar_kalman_update(0,    // y is missing, so fill in a dummy value
-                                  ks.a,
-                                  ks.P,
-                                  ks.K,
-                                  ks.F,
-                                  ks.v,
-                                  true,  // forecasts are missing data
-                                  observation_matrix(t+t0),
-                                  observation_variance(t+t0),
-                                  *state_transition_matrix(t+t0),
-                                  *state_variance_matrix(t+t0));
+    for(int t = 0; t < n; ++t) {
+      ans(t,0) = observation_matrix(t + t0).dot(ks.a);
+      sparse_scalar_kalman_update(
+          0,    // y is missing, so fill in a dummy value
+          ks.a,
+          ks.P,
+          ks.K,
+          ks.F,
+          ks.v,
+          true,  // forecasts are missing data
+          observation_matrix(t + t0),
+          observation_variance(t + t0),
+          *state_transition_matrix(t + t0),
+          *state_variance_matrix(t + t0));
       ans(t,1) = sqrt(ks.F);
     }
     return ans;
   }
 
-  Vector SSM::simulate_forecast(int n, const Vector &final_state){
+  Vector SSM::simulate_forecast(int n, const Vector &final_state) {
     StateSpaceModelBase::set_state_model_behavior(StateModel::MARGINAL);
     Vector ans(n);
     int t0 = time_dimension();
     Vector state = final_state;
     for(int t = 0; t < n; ++t) {
       state = simulate_next_state(state, t + t0);
-      ans[t] = rnorm(observation_matrix(t+t0).dot(state),
-                     sqrt(observation_variance(t+t0)));
+      ans[t] = rnorm(observation_matrix(t + t0).dot(state),
+                     sqrt(observation_variance(t + t0)));
     }
     return ans;
   }
 
   Vector SSM::simulate_forecast_given_observed_data(
-      int n, const Vector &observed_data){
+      int n, const Vector &observed_data) {
     StateSpaceModelBase::set_state_model_behavior(StateModel::MARGINAL);
     Vector ans(n);
     int t0 = observed_data.size();
     ScalarKalmanStorage ks(filter_observed_data(observed_data));
-    Vector state(rmvn(ks.a, ks.P));  //  this is state[t0], one after the final state
-    for(int t = 0; t < n; ++t){
-      ans[t] = rnorm(observation_matrix(t+t0).dot(state),
-                     sqrt(observation_variance(t+t0)));
+    //  'state' starts out as state[t0], which is one after the final
+    //  state.
+    Vector state(rmvn(ks.a, ks.P));
+    for (int t = 0; t < n; ++t) {
+      ans[t] = rnorm(observation_matrix(t + t0).dot(state),
+                     sqrt(observation_variance(t + t0)));
       state = simulate_next_state(state, t + t0 + 1);
     }
     StateSpaceModelBase::set_state_model_behavior(StateModel::MIXTURE);
     return ans;
   }
 
-  ScalarKalmanStorage SSM::filter_observed_data(const Vector &observed_data, int t0)const{
+  ScalarKalmanStorage SSM::filter_observed_data(const Vector &observed_data,
+                                                int t0) const {
     ScalarKalmanStorage ks(state_dimension());
     ks.a = initial_state_mean();
     ks.P = initial_state_variance();
@@ -153,7 +161,7 @@ namespace BOOM{
     int n = observed_data.size();
     if(n==0) return ks;
 
-    for(int t = 0; t < n; ++t){
+    for(int t = 0; t < n; ++t) {
       double y = observed_data[t];
       bool missing(y == BOOM::negative_infinity());
       sparse_scalar_kalman_update(y,
@@ -171,15 +179,16 @@ namespace BOOM{
     return ks;
   }
 
-  Vector SSM::one_step_holdout_prediction_errors(const Vector &newY,
-                                              const Vector &final_state)const{
+  Vector SSM::one_step_holdout_prediction_errors(
+      const Vector &newY,
+      const Vector &final_state) const {
     Vector ans(length(newY));
     const std::vector<Ptr<DoubleData> > &data(dat());
     int t0 = data.size();
     ScalarKalmanStorage ks(state_dimension());
     ks.a = *state_transition_matrix(t0 - 1) * final_state;
     ks.P = SpdMatrix(state_variance_matrix(t0-1)->dense());
-    for(int t = 0; t < ans.size(); ++t){
+    for(int t = 0; t < ans.size(); ++t) {
       bool missing = false;
       sparse_scalar_kalman_update(newY[t],
                                   ks.a,
@@ -189,11 +198,12 @@ namespace BOOM{
                                   ks.v,
                                   missing,
                                   observation_matrix(t + t0),
-                                  observation_variance(t+t0),
-                                  *state_transition_matrix(t+t0),
-                                  *state_variance_matrix(t+t0));
+                                  observation_variance(t + t0),
+                                  *state_transition_matrix(t + t0),
+                                  *state_variance_matrix(t + t0));
       ans[t] = ks.v;
     }
     return ans;
   }
-}
+
+}  // namespace BOOM
